@@ -2,10 +2,24 @@
 Created by Axel Thevenot (2020)
 Github repository: https://github.com/AxelThevenot/Python_Benchmark_Test_Optimization_Function_Single_Objective
 """
+#                                                                       Modules
+# =============================================================================
+
+# Third-party
 import autograd.numpy as np
 
+# Locals
 from ..functions.adapters.pybenchfunction import PyBenchFunction
 
+#                                                          Authorship & Credits
+# =============================================================================
+__author__ = 'Martin van der Schelling (M.P.vanderSchelling@tudelft.nl)'
+__credits__ = ['Martin van der Schelling']
+__status__ = 'Stable'
+# =============================================================================
+#
+# =============================================================================
+
 
 class Thevenot(PyBenchFunction):
     """.. image:: ../img/functions/Thevenot.png"""
@@ -28,7 +42,8 @@ class Thevenot(PyBenchFunction):
 
     def _set_parameters(self, m=5, beta=15):
         d = self.dimensionality
-        self.input_domain = np.array([[-2 * np.pi, 2 * np.pi] for _ in range(d)])
+        self.input_domain = np.array(
+            [[-2 * np.pi, 2 * np.pi] for _ in range(d)])
         self.m = m
         self.beta = beta
 
@@ -91,7 +106,7 @@ class AckleyN2(PyBenchFunction):
     """.. image:: ../img/functions/AckleyN2.png"""
 
     name = "Ackley N. 2"
-    continuous = False
+    continuous = True
     convex = True
     separable = False
     differentiable = True
@@ -126,7 +141,7 @@ class AckleyN3(PyBenchFunction):
     """.. image:: ../img/functions/AckleyN3.png"""
 
     name = "Ackley N. 3"
-    continuous = False
+    continuous = True
     convex = False
     separable = False
     differentiable = True
@@ -162,7 +177,7 @@ class AckleyN4(PyBenchFunction):
     """.. image:: ../img/functions/AckleyN4.png"""
 
     name = "Ackley N. 4"
-    continuous = False
+    continuous = True
     convex = False
     separable = False
     differentiable = True
@@ -194,7 +209,8 @@ class AckleyN4(PyBenchFunction):
 
     def evaluate(self, X):
         X, Xp1 = X[:-1], X[1]
-        res = np.sum(np.exp(-0.2) * np.sqrt(X**2 + Xp1**2) + 3 * np.cos(2 * X) + np.sin(2 * Xp1))
+        res = np.sum(np.exp(-0.2) * np.sqrt(
+            X**2 + Xp1**2) + 3 * np.cos(2 * X) + np.sin(2 * Xp1))
         return res
 
 
@@ -240,7 +256,7 @@ class Bartels(PyBenchFunction):
     """.. image:: ../img/functions/Bartels.png"""
 
     name = "Bartels"
-    continuous = False
+    continuous = True
     convex = False
     separable = False
     differentiable = False
@@ -268,7 +284,8 @@ class Bartels(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = np.abs(x**2 + y**2 + x * y) + np.abs(np.sin(x)) + np.abs(np.cos(y))
+        res = np.abs(x**2 + y**2 + x * y) + \
+            np.abs(np.sin(x)) + np.abs(np.cos(y))
         return res
 
 
@@ -329,7 +346,8 @@ class Bird(PyBenchFunction):
 
     def _set_parameters(self):
         d = self.dimensionality
-        self.input_domain = np.array([[-2 * np.pi, 2 * np.pi], [-2 * np.pi, 2 * np.pi]])
+        self.input_domain = np.array(
+            [[-2 * np.pi, 2 * np.pi], [-2 * np.pi, 2 * np.pi]])
 
     def get_param(self):
         return {}
@@ -377,7 +395,8 @@ class BohachevskyN1(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = x**2 + 2 * y**2 - 0.3 * np.cos(3 * np.pi * x) - 0.4 * np.cos(4 * np.pi * y) + 0.7
+        res = x**2 + 2 * y**2 - 0.3 * \
+            np.cos(3 * np.pi * x) - 0.4 * np.cos(4 * np.pi * y) + 0.7
         return res
 
 
@@ -413,7 +432,8 @@ class BohachevskyN2(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = x**2 + 2 * y**2 - 0.3 * np.cos(3 * np.pi * x) * np.cos(4 * np.pi * y) + 0.3
+        res = x**2 + 2 * y**2 - 0.3 * \
+            np.cos(3 * np.pi * x) * np.cos(4 * np.pi * y) + 0.3
         return res
 
 
@@ -449,7 +469,8 @@ class BohachevskyN3(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = x**2 + 2 * y**2 - 0.3 * np.cos(3 * np.pi * x + 4 * np.pi * y) * np.cos(4 * np.pi * y) + 0.3
+        res = x**2 + 2 * y**2 - 0.3 * \
+            np.cos(3 * np.pi * x + 4 * np.pi * y) * np.cos(4 * np.pi * y) + 0.3
         return res
 
 
@@ -685,10 +706,11 @@ class BukinN6(PyBenchFunction):
         #         return (self._retrieve_original_input(X), self(self._retrieve_original_input(X)))
 
         #     def evaluate(self, X):
-        x1, x2, x3, x4 = X
-        res = 100 * (x1**2 - x2) ** 2 + (x1 - 1) ** 2 + (x3 - 1) ** 2
-        res = res + 90 * (x3**2 - x4) ** 2 + 10.1 * ((x2 - 1) ** 2 + (x4 - 1) ** 2) + 19.8 * (x2 - 1) * (x4 - 1)
-        return res
+        # x1, x2, x3, x4 = X
+        # res = 100 * (x1**2 - x2) ** 2 + (x1 - 1) ** 2 + (x3 - 1) ** 2
+        # res = res + 90 * (x3**2 - x4) ** 2 + 10.1 * ((x2 - 1)
+        #                                             ** 2 + (x4 - 1) ** 2) + 19.8 * (x2 - 1) * (x4 - 1)
+        # return res
 
 
 class CrossInTray(PyBenchFunction):
@@ -731,8 +753,8 @@ class CrossInTray(PyBenchFunction):
     def evaluate(self, X):
         x, y = X
         res = (
-            -0.0001
-            * (np.abs(np.sin(x) * np.sin(y)) * np.exp(np.abs(100 - np.sqrt(x**2 + y**2) / np.pi)) + 1) ** 0.1
+            -0.0001 * (np.abs(np.sin(x) * np.sin(y)) * np.exp(
+                np.abs(100 - np.sqrt(x**2 + y**2) / np.pi)) + 1) ** 0.1
         )
         return res
 
@@ -761,7 +783,8 @@ class DeJongN5(PyBenchFunction):
         self.input_domain = np.array([[-65.536, 65.536], [-65.536, 65.536]])
         if a is None:
             l_parameter = [-32, -16, 0, 16, 32]
-            self.a = np.array([[x, y] for x in l_parameter for y in l_parameter])
+            self.a = np.array([[x, y]
+                              for x in l_parameter for y in l_parameter])
         else:
             self.a = a
 
@@ -775,7 +798,8 @@ class DeJongN5(PyBenchFunction):
     def evaluate(self, X):
         x, y = X
         res = (
-            0.002 + np.sum([1 / ((i + 1) + (x - a1) ** 6 + (y - a2) ** 6) for i, (a1, a2) in enumerate(self.a)])
+            0.002 + np.sum([1 / ((i + 1) + (x - a1) ** 6 + (y - a2) ** 6)
+                           for i, (a1, a2) in enumerate(self.a)])
         ) ** -1
         return res
 
@@ -843,12 +867,14 @@ class DixonPrice(PyBenchFunction):
         return {}
 
     def get_global_minimum(self, d):
-        X = np.array([2 ** ((-(2 ** (i)) - 2) / 2**i) for i in range(1, d + 1)])
+        X = np.array([2 ** ((-(2 ** (i)) - 2) / 2**i)
+                     for i in range(1, d + 1)])
         return (self._retrieve_original_input(X), self(self._retrieve_original_input(X)))
 
     def evaluate(self, X):
         d = X.shape[0]
-        res = (X[0] - 1) ** 2 + np.sum([(i + 1) * (2 * X[i] ** 2 - X[i - 1]) ** 2 for i in range(1, d)])
+        res = (X[0] - 1) ** 2 + np.sum(
+            [(i + 1) * (2 * X[i] ** 2 - X[i - 1]) ** 2 for i in range(1, d)])
         return res
 
 
@@ -884,7 +910,8 @@ class DropWave(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = -(1 + np.cos(12 * np.sqrt(x**2 + y**2))) / (0.5 * (x**2 + y**2) + 2)
+        res = -(1 + np.cos(12 * np.sqrt(x**2 + y**2))) / \
+            (0.5 * (x**2 + y**2) + 2)
         return res
 
 
@@ -920,7 +947,8 @@ class Easom(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = -np.cos(x) * np.cos(y) * np.exp(-((x - np.pi) ** 2) - (y - np.pi) ** 2)
+        res = -np.cos(x) * np.cos(y) * \
+            np.exp(-((x - np.pi) ** 2) - (y - np.pi) ** 2)
         return res
 
 
@@ -964,7 +992,7 @@ class EggHolder(PyBenchFunction):
     """.. image:: ../img/functions/EggHolder.png"""
 
     name = "Egg Holder"
-    continuous = False
+    continuous = True
     convex = False
     separable = False
     differentiable = True
@@ -992,7 +1020,8 @@ class EggHolder(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = -(y + 47) * np.sin(np.sqrt(np.abs(y + x / 2 + 47))) - x * np.sin(np.sqrt(np.abs(x - y - 47)))
+        res = -(y + 47) * np.sin(np.sqrt(np.abs(y + x / 2 + 47))) - \
+            x * np.sin(np.sqrt(np.abs(x - y - 47)))
         return res
 
 
@@ -1036,7 +1065,7 @@ class GoldsteinPrice(PyBenchFunction):
     """.. image:: ../img/functions/GoldsteinPrice.png"""
 
     name = "Goldstein-Price"
-    continuous = False
+    continuous = True
     convex = False
     separable = False
     differentiable = True
@@ -1065,7 +1094,8 @@ class GoldsteinPrice(PyBenchFunction):
     def evaluate(self, X):
         x, y = X
         res = 1 + (x + y + 1) ** 2 * (19 - 14 * x + 3 * x**2 - 14 * y + 6 * x * y + 3 * y**2)
-        res *= 30 + (2 * x - 3 * y) ** 2 * (18 - 32 * x + 12 * x**2 + 48 * y - 36 * x * y + 27 * y**2)
+        res *= 30 + (2 * x - 3 * y) ** 2 * (
+            18 - 32 * x + 12 * x**2 + 48 * y - 36 * x * y + 27 * y**2)
         return res
 
 
@@ -1140,7 +1170,8 @@ class HappyCat(PyBenchFunction):
     def evaluate(self, X):
         d = X.shape[0]
         norm = np.sum(X**2)
-        res = ((norm - d) ** 2) ** self.alpha + (1 / d) * (0.5 * norm + np.sum(X)) + 0.5
+        res = ((norm - d) ** 2) ** self.alpha + \
+            (1 / d) * (0.5 * norm + np.sum(X)) + 0.5
         return res
 
 
@@ -1226,7 +1257,8 @@ class HolderTable(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = -np.abs(np.sin(x) * np.cos(y) * np.exp(np.abs(1 - np.sqrt(x**2 + y**2) / np.pi)))
+        res = -np.abs(np.sin(x) * np.cos(y) * np.exp(
+            np.abs(1 - np.sqrt(x**2 + y**2) / np.pi)))
         return res
 
 
@@ -1290,7 +1322,8 @@ class Langermann(PyBenchFunction):
         self.input_domain = np.array([[0, 10] for _ in range(d)])
         self.m = m if m is not None else 5
         self.c = c if c is not None else np.array([1, 2, 5, 2, 3])
-        self.A = A if A is not None else np.array([[3, 5], [5, 2], [2, 1], [1, 4], [7, 9]])
+        self.A = A if A is not None else np.array(
+            [[3, 5], [5, 2], [2, 1], [1, 4], [7, 9]])
 
     def get_param(self):
         return {"m": self.m, "c": self.c, "A": self.A}
@@ -1303,9 +1336,9 @@ class Langermann(PyBenchFunction):
         d = X.shape[0]
         res = np.sum(
             [
-                self.c[i]
-                * np.exp(-1 / np.pi * np.sum((X - self.A[i]) ** 2))
-                * np.cos(np.pi * np.sum((X - self.A[i]) ** 2))
+                self.c[i] * np.exp(-1 / np.pi * np.sum(
+                    (X - self.A[i]) ** 2)) * np.cos(
+                        np.pi * np.sum((X - self.A[i]) ** 2))
                 for i in range(self.m)
             ]
         )
@@ -1381,9 +1414,10 @@ class Levy(PyBenchFunction):
     def evaluate(self, X):
         z = 1 + (X - 1) / 4
         res = (
-            np.sin(np.pi * z[0]) ** 2
-            + sum((z[:-1] - 1) ** 2 * (1 + 10 * np.sin(np.pi * z[:-1] + 1) ** 2))
-            + (z[-1] - 1) ** 2 * (1 + np.sin(2 * np.pi * z[-1]) ** 2)
+            np.sin(np.pi * z[0]) ** 2 + sum(
+                (z[:-1] - 1) ** 2 * (1 + 10 * np.sin(
+                    np.pi * z[:-1] + 1) ** 2)) + (
+                        z[-1] - 1) ** 2 * (1 + np.sin(2 * np.pi * z[-1]) ** 2)
         )
         return res
 
@@ -1421,9 +1455,9 @@ class LevyN13(PyBenchFunction):
     def evaluate(self, X):
         x, y = X
         res = (
-            np.sin(3 * np.pi * x) ** 2
-            + (x - 1) ** 2 * (1 + np.sin(3 * np.pi * y) ** 2)
-            + (y - 1) ** 2 * (1 + np.sin(2 * np.pi * y) ** 2)
+            np.sin(3 * np.pi * x) ** 2 + (x - 1) ** 2 * (
+                1 + np.sin(3 * np.pi * y) ** 2) + (y - 1) ** 2 * (
+                    1 + np.sin(2 * np.pi * y) ** 2)
         )
         return res
 
@@ -1611,7 +1645,8 @@ class PermZeroDBeta(PyBenchFunction):
         d = X.shape[0]
         res = np.sum(
             [
-                (np.sum([((j + 1) + self.beta * (X[j] ** (i + 1) - j ** (i + 1))) for j in range(d)])) ** 2
+                (np.sum([((j + 1) + self.beta * (X[j] ** (i + 1) - j ** (i + 1)))
+                 for j in range(d)])) ** 2
                 for i in range(d)
             ]
         )
@@ -1652,7 +1687,8 @@ class PermDBeta(PyBenchFunction):
     def evaluate(self, X):
         d = X.shape[0]
         j = np.arange(1, d + 1)
-        res = np.sum([np.sum((j**i + self.beta) * ((X / j) ** i - 1)) ** 2 for i in range(1, d + 1)])
+        res = np.sum([np.sum((j**i + self.beta) * (
+            (X / j) ** i - 1)) ** 2 for i in range(1, d + 1)])
         return res
 
 
@@ -1882,7 +1918,8 @@ class Rosenbrock(PyBenchFunction):
 
     def evaluate(self, X):
         d = X.shape[0]
-        res = np.sum(np.abs(self.b * (X[1:] - X[:-1] ** 2) ** 2 + (self.a - X[:-1]) ** 2))
+        res = np.sum(
+            np.abs(self.b * (X[1:] - X[:-1] ** 2) ** 2 + (self.a - X[:-1]) ** 2))
         return res
 
 
@@ -1995,7 +2032,8 @@ class SchaffelN1(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = 0.5 + (np.sin((x**2 + y**2) ** 2) ** 2 - 0.5) / (1 + 0.001 * (x**2 + y**2)) ** 2
+        res = 0.5 + (np.sin((x**2 + y**2) ** 2) ** 2 - 0.5) / \
+            (1 + 0.001 * (x**2 + y**2)) ** 2
         return res
 
 
@@ -2031,7 +2069,8 @@ class SchaffelN2(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = 0.5 + (np.sin((x**2 + y**2)) ** 2 - 0.5) / (1 + 0.001 * (x**2 + y**2)) ** 2
+        res = 0.5 + (np.sin((x**2 + y**2)) ** 2 - 0.5) / \
+            (1 + 0.001 * (x**2 + y**2)) ** 2
         return res
 
 
@@ -2067,7 +2106,9 @@ class SchaffelN3(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = 0.5 + (np.sin(np.cos(np.abs(x**2 + y**2))) ** 2 - 0.5) / (1 + 0.001 * (x**2 + y**2)) ** 2
+        res = 0.5 + (np.sin(np.cos(
+            np.abs(x**2 + y**2))) ** 2 - 0.5) / (
+                1 + 0.001 * (x**2 + y**2)) ** 2
         return res
 
 
@@ -2103,7 +2144,9 @@ class SchaffelN4(PyBenchFunction):
 
     def evaluate(self, X):
         x, y = X
-        res = 0.5 + (np.cos(np.sin(np.abs(x**2 + y**2))) ** 2 - 0.5) / (1 + 0.001 * (x**2 + y**2)) ** 2
+        res = 0.5 + (np.cos(np.sin(np.abs(
+            x**2 + y**2))) ** 2 - 0.5) / (
+                1 + 0.001 * (x**2 + y**2)) ** 2
         return res
 
 
@@ -2389,7 +2432,8 @@ class Shubert(PyBenchFunction):
     def evaluate(self, X):
         d = X.shape[0]
         for i in range(0, d):
-            res = np.prod(np.sum([i * np.cos((j + 1) * X[i] + j) for j in range(1, 5 + 1)]))
+            res = np.prod(np.sum([i * np.cos((j + 1) * X[i] + j)
+                          for j in range(1, 5 + 1)]))
         return res
 
 
@@ -2428,7 +2472,8 @@ class ShubertN3(PyBenchFunction):
 
     def evaluate(self, X):
         d = X.shape[0]
-        res = np.sum(np.sum([j * np.sin((j + 1) * X + j) for j in range(1, 5 + 1)]))
+        res = np.sum(np.sum([j * np.sin((j + 1) * X + j)
+                     for j in range(1, 5 + 1)]))
         return res
 
 
@@ -2466,7 +2511,8 @@ class ShubertN4(PyBenchFunction):
 
     def evaluate(self, X):
         d = X.shape[0]
-        res = np.sum(np.sum([j * np.cos((j + 1) * X + j) for j in range(1, 5 + 1)]))
+        res = np.sum(np.sum([j * np.cos((j + 1) * X + j)
+                     for j in range(1, 5 + 1)]))
         return res
 
 
@@ -2508,10 +2554,10 @@ class Sphere(PyBenchFunction):
         return res
 
 
-class StyblinskiTank(PyBenchFunction):
-    """.. image:: ../img/functions/StyblinskiTank.png"""
+class StyblinskiTang(PyBenchFunction):
+    """.. image:: ../img/functions/StyblinskiTang.png"""
 
-    name = "Styblinski Tank"
+    name = "Styblinski Tang"
     continuous = True
     convex = False
     separable = True
@@ -2652,7 +2698,7 @@ class Trid(PyBenchFunction):
     def evaluate(self, X):
         d = X.shape[0]
         i = np.arange(1, d + 1)
-        res = np.sum(X - 1) ** 2 - np.sum(X[1:] * X[:-1])
+        res = np.sum((X - 1) ** 2) - np.sum(X[1:] * X[:-1])
         return res
 
 
@@ -2696,7 +2742,7 @@ class XinSheYang(PyBenchFunction):
     """.. image:: ../img/functions/XinSheYang.png"""
 
     name = "Xin She Yang"
-    continuous = False
+    continuous = True
     convex = False
     separable = True
     differentiable = False
@@ -2751,7 +2797,8 @@ class XinSheYangN2(PyBenchFunction):
 
     def _set_parameters(self):
         d = self.dimensionality
-        self.input_domain = np.array([[-2 * np.pi, 2 * np.pi] for _ in range(d)])
+        self.input_domain = np.array(
+            [[-2 * np.pi, 2 * np.pi] for _ in range(d)])
 
     def get_param(self):
         return {}
@@ -2787,7 +2834,8 @@ class XinSheYangN3(PyBenchFunction):
 
     def _set_parameters(self, m=5, beta=15):
         d = self.dimensionality
-        self.input_domain = np.array([[-2 * np.pi, 2 * np.pi] for _ in range(d)])
+        self.input_domain = np.array(
+            [[-2 * np.pi, 2 * np.pi] for _ in range(d)])
         self.m = m
         self.beta = beta
 
@@ -2837,7 +2885,8 @@ class XinSheYangN4(PyBenchFunction):
 
     def evaluate(self, X):
         d = X.shape[0]
-        res = np.sum(np.sin(X) ** 2 - np.exp(-np.sum(X) ** 2)) * np.exp(-np.sum(np.sin(np.sqrt(np.abs(X))) ** 2))
+        res = np.sum(np.sin(X) ** 2 - np.exp(-np.sum(X) ** 2)) * \
+            np.exp(-np.sum(np.sin(np.sqrt(np.abs(X))) ** 2))
         return res
 
 
@@ -2845,7 +2894,7 @@ class Zakharov(PyBenchFunction):
     """.. image:: ../img/functions/Zakharov.png"""
 
     name = "Zakharov"
-    continuous = False
+    continuous = True
     convex = False
     separable = False
     differentiable = False
@@ -2874,5 +2923,6 @@ class Zakharov(PyBenchFunction):
     def evaluate(self, X):
         d = X.shape[0]
         i = np.arange(1, d + 1)
-        res = np.sum(X**2) + np.sum(0.5 * i * X) ** 2 + np.sum(0.5 * i * X) ** 4
+        res = np.sum(X**2) + np.sum(0.5 * i * X) ** 2 + \
+            np.sum(0.5 * i * X) ** 4
         return res
